<?php

use Zend\ServiceManager\ServiceManager;
use Zend\Mvc\Service\ServiceManagerConfig;
use Zend\ModuleManager\Listener\ConfigListener;
use Zend\ModuleManager\Listener\ListenerOptions;
use Zend\ModuleManager\ModuleEvent;

class Bootstrap extends Yaf_Bootstrap_Abstract {

    public function _initConfig() {
        $config = Yaf_Application::app()->getConfig();
        Yaf_Registry::set("config", $config);
    }

    public function _initServiceManager() {
        $configuration = require APP_PATH . '/conf/application.config.php';
        $smConfig = isset($configuration['service_manager']) ? $configuration['service_manager'] : array();
        $serviceManager = new ServiceManager(new ServiceManagerConfig($smConfig));
        $serviceManager->setService('ApplicationConfig', $configuration);

        $configListener = new ConfigListener(new ListenerOptions($configuration['module_listener_options']));

        // If not found cache, merge config
        if (!$configListener->getMergedConfig(false)) $configListener->onMergeConfig(new ModuleEvent);

        // If enabled, update the config cache
        if ($configListener->getOptions()->getConfigCacheEnabled() &&
                !file_exists($configListener->getOptions()->getConfigCacheFile())) {
            $configFile = $configListener->getOptions()->getConfigCacheFile();
            $content = "<?php\nreturn " . var_export($configListener->getMergedConfig(false), 1) . ';';
            file_put_contents($configFile, $content);
        }

        $serviceManager->setService('config', $configListener->getMergedConfig(false));


        Yaf_Registry::set('ServiceManager', $serviceManager);
    }

    public function _initSessionManager() {
        Yaf_Registry::get('ServiceManager')->get('Zend\Session\SessionManager');
    }

    public function _initPlugin(Yaf_Dispatcher $dispatcher) {
        $user = new UserPlugin();
        $dispatcher->registerPlugin($user);
    }

}
