<?php

class ErrorController extends Yaf_Controller_Abstract {

    /**
     * error handler
     * @param \Exception $exception
     * @return void
     */
    public function errorAction(Exception $exception) {
        switch ($exception->getCode()) {
            case YAF_ERR_NOTFOUND_MODULE:
            case YAF_ERR_NOTFOUND_CONTROLLER:
            case YAF_ERR_NOTFOUND_ACTION:
                // 404 error -- controller or action not found
                http_response_code(404);
                $priority = \Zend\Log\Logger::NOTICE;
                $this->getView()->assign('message', 'Page not found');
                break;
            default:
                // application error
                http_response_code(500);
                $priority = \Zend\Log\Logger::CRIT;
                $this->getView()->assign('message', 'Application error');
                break;
        }

        // Log exception, if logger available
        if ($logger = $this->getLogger()) {
            $logger->log($priority, $this->getView()->get('message'), $this->getRequest()->getParams());
            $logger->log($priority, 'Request Parameters', $this->getRequest()->getQuery());
        }

        $this->getView()->assign('exception', $exception);
        $this->getView()->assign('request', $this->getRequest());
    }

    /**
     * logger
     * @return \Zend\Log\Logger
     */
    protected function getLogger() {
        return Yaf_Registry::get('ServiceManager')->get('Zend\Log\Logger');
    }

}
